"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Level;
(function (Level) {
    Level["ERROR"] = "ERROR";
    Level["DEFAULT"] = "DEFAULT";
    Level["DEBUG"] = "DEBUG";
})(Level || (Level = {}));
class Logging {
    constructor(log = cloudWatch(console.log), error = cloudWatch(console.error), debug = cloudWatch(console.info)) {
        this.log = (...args) => {
            if (this.logLevel === Level.ERROR) {
                return;
            }
            this._log({ level: Level.DEFAULT, data: args });
        };
        this.debug = (...args) => {
            if (this.logLevel !== Level.DEBUG) {
                return;
            }
            this._debug({ level: Level.DEBUG, data: args });
        };
        this.error = (err, ...args) => {
            this._error({
                level: Level.ERROR,
                errorMessage: err.message,
                stack: err.stack,
                error: err,
                data: args,
            });
        };
        this._log = log;
        this._error = error;
        this._debug = debug;
        this.logLevel = (process.env.LOG_LEVEL || Level.DEFAULT);
    }
}
Logging.log = (...args) => {
    new Logging().log(...args);
};
Logging.error = (err, ...args) => {
    new Logging().error(err, ...args);
};
Logging.debug = (...args) => {
    new Logging().debug(...args);
};
exports.Logging = Logging;
// AWS CloudWatch supports filtering by JSON properties, IF logging pure JSON objects as strings
const cloudWatch = (log) => (logArg) => {
    log(JSON.stringify(logArg, null, 2));
};
